@@ -11,7 +11,7 @@ use DateTime::TimeZone 0.06;
 use DateTime::TimeZone::UTC;
 use DateTime::TimeZone::Floating;
 
-$VERSION = '0.16009';
+$VERSION = '0.16010';
 $VERSION = eval $VERSION;
 
 our @ISA = ('DateTime::Format::Builder');
@@ -561,19 +561,23 @@ If given an improperly formatted string, this method may die.
 
 sub parse_duration {
     my ($self, $string) = @_;
-    my ($year, $mon, $day, $sgn, $hour, $min, $sec, $frc, $ago) = $string =~ m{
+    my ($mil, $cent, $dec, $year, $mon, $wk, $day, $sgn, $hour, $min, $sec, $frc, $ago) = $string =~ m{
         \A                                     # Start of string.
         (?:\@\s*)?                             # Optional leading @.
-        (?:([-+]?\d+)\s+years?\s*)?            # years
-        (?:([-+]?\d+)\s+mons?\s*)?             # months
-        (?:([-+]?\d+)\s+days?\s*)?             # days
+        (?:([-+]?\d+)\s+(?:millennium|millennia|millenniums|mil|mils)\s*)?  # millennia
+        (?:([-+]?\d+)\s+(?:century|centuries|cent|c)\s*)?                   # centuries
+        (?:([-+]?\d+)\s+(?:decade|decades|dec|decs)\s*)?                    # decades
+        (?:([-+]?\d+)\s+(?:year|years|yr|yrs|y)\s*)?                        # years
+        (?:([-+]?\d+)\s+(?:month|months|mon|mons)\s*)?                      # months
+        (?:([-+]?\d+)\s+(?:week|weeks|w)\s*)?                               # weeks
+        (?:([-+]?\d+)\s+(?:day|days|d)\s*)?                                 # days
         (?:                                    # Start h/m/s
           # hours
           (?:([-+])?([0-9]\d|[1-9]\d{2,}(?=:)|\d+(?=\s+hour))(?:\s+hours?)?\s*)?
           # minutes
-          (?::?((?<=:)[012345]\d|\d+(?=\s+mins?))(?:\s+mins?)?\s*)?
+          (?::?((?<=:)[012345]\d|\d+(?=\s+min(?:ute)?s?))(?:\s+min(?:ute)?s?)?\s*)?
           # seconds
-          (?::?((?<=:)[012345]\d|\d+(?=\.|\s+secs?))(\.\d+)?(?:\s+secs?)?\s*)?
+          (?::?((?<=:)[012345]\d|\d+(?=\.|\s+sec(?:ond)?s?))(\.\d+)?(?:\s+sec(?:ond)?s?)?\s*)?
         ?)                                     # End hh:mm:ss
         (ago)?                                 # Optional inversion
         \z                                     # End of string
@@ -589,7 +593,11 @@ sub parse_duration {
 
     # DT::Duration only stores years, days, months, seconds (and
     # nanoseconds)
+    $year += 1000 * $mil if $mil;
+    $year += 100 * $cent if $cent;
+    $year += 10 * $dec   if $dec;
     $mon += 12 * $year if $year;
+    $day +=  7 *   $wk if $wk;
     $min += 60 * $hour if $hour;
 
     # HH:MM:SS.FFFF share a single sign
